# ifndef GEO_GRID_H
# define GEO_GRID_H

#   define	COORDtoGRID(xmag,t) ((int)((xmag)*(t)))
#   define	GRIDtoCOORD(p,xmag) ((int)((p)/(xmag)))

# endif /* GEO_GRID_H */
